summaryrefslogtreecommitdiff
path: root/sw/source/ui/app
diff options
context:
space:
mode:
authorJan Holesovsky <kendy@collabora.com>2013-10-16 16:36:45 +0200
committerJan Holesovsky <kendy@collabora.com>2013-10-16 16:57:22 +0200
commit66013a154bd2dccc0db1edd14197ce419ba9a614 (patch)
tree0698af88b8d236e98bafa6848f73851e0b752f15 /sw/source/ui/app
parentd62b71bddedccb6ff29090f621cc0803565332ec (diff)
[API CHANGE]: PreView -> Preview, including .uno:PrintPagePreView.
Will be .uno:PrintPagePreview going forward. Change-Id: Ie5a35467917a54a60dab9eaacf0690c9df27e6f6
Diffstat (limited to 'sw/source/ui/app')
-rw-r--r--sw/source/ui/app/apphdl.cxx8
-rw-r--r--sw/source/ui/app/appopt.cxx2
-rw-r--r--sw/source/ui/app/docsh.cxx4
-rw-r--r--sw/source/ui/app/docsh2.cxx8
-rw-r--r--sw/source/ui/app/swmodul1.cxx6
-rw-r--r--sw/source/ui/app/swmodule.cxx4
6 files changed, 16 insertions, 16 deletions
diff --git a/sw/source/ui/app/apphdl.cxx b/sw/source/ui/app/apphdl.cxx
index 0f6c57c1d602..cf21d0f3fb06 100644
--- a/sw/source/ui/app/apphdl.cxx
+++ b/sw/source/ui/app/apphdl.cxx
@@ -761,7 +761,7 @@ void SwModule::ConfigurationChanged( utl::ConfigurationBroadcaster* pBrdCst, sal
//invalidate all edit windows
const TypeId aSwViewTypeId = TYPE(SwView);
- const TypeId aSwPreViewTypeId = TYPE(SwPagePreView);
+ const TypeId aSwPreviewTypeId = TYPE(SwPagePreview);
const TypeId aSwSrcViewTypeId = TYPE(SwSrcView);
SfxViewShell* pViewShell = SfxViewShell::GetFirst();
while(pViewShell)
@@ -769,15 +769,15 @@ void SwModule::ConfigurationChanged( utl::ConfigurationBroadcaster* pBrdCst, sal
if(pViewShell->GetWindow())
{
if((pViewShell->IsA(aSwViewTypeId) ||
- pViewShell->IsA(aSwPreViewTypeId) ||
+ pViewShell->IsA(aSwPreviewTypeId) ||
pViewShell->IsA(aSwSrcViewTypeId)))
{
if(bAccessibility)
{
if(pViewShell->IsA(aSwViewTypeId))
((SwView*)pViewShell)->ApplyAccessiblityOptions(*pAccessibilityOptions);
- else if(pViewShell->IsA(aSwPreViewTypeId))
- ((SwPagePreView*)pViewShell)->ApplyAccessiblityOptions(*pAccessibilityOptions);
+ else if(pViewShell->IsA(aSwPreviewTypeId))
+ ((SwPagePreview*)pViewShell)->ApplyAccessiblityOptions(*pAccessibilityOptions);
}
pViewShell->GetWindow()->Invalidate();
}
diff --git a/sw/source/ui/app/appopt.cxx b/sw/source/ui/app/appopt.cxx
index ea719eace8fb..238229ee05e5 100644
--- a/sw/source/ui/app/appopt.cxx
+++ b/sw/source/ui/app/appopt.cxx
@@ -169,7 +169,7 @@ SfxItemSet* SwModule::CreateItemSet( sal_uInt16 nId )
}
if(bTextDialog)
pRet->Put(SwPtrItem(FN_PARAM_STDFONTS, GetStdFontConfig()));
- if( PTR_CAST( SwPagePreView, SfxViewShell::Current())!=0)
+ if( PTR_CAST( SwPagePreview, SfxViewShell::Current())!=0)
{
SfxBoolItem aBool(SfxBoolItem(SID_PRINTPREVIEW, sal_True));
pRet->Put(aBool);
diff --git a/sw/source/ui/app/docsh.cxx b/sw/source/ui/app/docsh.cxx
index da74ba9afdb0..617e2e9ad779 100644
--- a/sw/source/ui/app/docsh.cxx
+++ b/sw/source/ui/app/docsh.cxx
@@ -832,7 +832,7 @@ Rectangle SwDocShell::GetVisArea( sal_uInt16 nAspect ) const
{
if ( nAspect == ASPECT_THUMBNAIL )
{
- // PreView: set VisArea to the first page.
+ // Preview: set VisArea to the first page.
SwNodeIndex aIdx( pDoc->GetNodes().GetEndOfExtras(), 1 );
SwCntntNode* pNd = pDoc->GetNodes().GoNext( &aIdx );
@@ -933,7 +933,7 @@ void SwDocShell::GetState(SfxItemSet& rSet)
else
{
SfxBoolItem aBool( SID_PRINTPREVIEW, sal_False );
- if( PTR_CAST( SwPagePreView, SfxViewShell::Current()) )
+ if( PTR_CAST( SwPagePreview, SfxViewShell::Current()) )
aBool.SetValue( sal_True );
rSet.Put( aBool );
}
diff --git a/sw/source/ui/app/swmodul1.cxx b/sw/source/ui/app/swmodul1.cxx
index 235410ecc81c..0bda79bb447c 100644
--- a/sw/source/ui/app/swmodul1.cxx
+++ b/sw/source/ui/app/swmodul1.cxx
@@ -152,9 +152,9 @@ void SwModule::ApplyUsrPref(const SwViewOption &rUsrPref, SwView* pActView,
// with Uno, only sdbcx::View, but not the Module should be changed
bool bViewOnly = VIEWOPT_DEST_VIEW_ONLY == nDest;
- // fob PreView off
- SwPagePreView* pPPView;
- if( !pCurrView && 0 != (pPPView = PTR_CAST( SwPagePreView, SfxViewShell::Current())) )
+ // fob Preview off
+ SwPagePreview* pPPView;
+ if( !pCurrView && 0 != (pPPView = PTR_CAST( SwPagePreview, SfxViewShell::Current())) )
{
if(!bViewOnly)
pPref->SetUIOptions( rUsrPref );
diff --git a/sw/source/ui/app/swmodule.cxx b/sw/source/ui/app/swmodule.cxx
index 72f745f58a0c..cab58197017d 100644
--- a/sw/source/ui/app/swmodule.cxx
+++ b/sw/source/ui/app/swmodule.cxx
@@ -248,7 +248,7 @@ void SwDLL::RegisterFactories()
if ( SvtModuleOptions().IsWriter() )
{
SwSrcView::RegisterFactory ( 6 );
- SwPagePreView::RegisterFactory ( 7 );
+ SwPagePreview::RegisterFactory ( 7 );
}
}
@@ -262,7 +262,7 @@ void SwDLL::RegisterInterfaces()
SwWebGlosDocShell::RegisterInterface( pMod );
SwView::RegisterInterface( pMod );
SwWebView::RegisterInterface( pMod );
- SwPagePreView::RegisterInterface( pMod );
+ SwPagePreview::RegisterInterface( pMod );
SwSrcView::RegisterInterface( pMod );
diff --git a/sw/source/ui/app/docsh2.cxx b/sw/source/ui/app/docsh2.cxx
index 82341c7f7472..25140295dbeb 100644
--- a/sw/source/ui/app/docsh2.cxx
+++ b/sw/source/ui/app/docsh2.cxx
@@ -403,13 +403,13 @@ void SwDocShell::Execute(SfxRequest& rReq)
SfxViewFrame *pTmpFrm = SfxViewFrame::GetFirst(this);
SfxViewShell* pViewShell = SfxViewShell::Current();
SwView* pCurrView = dynamic_cast< SwView *> ( pViewShell );
- sal_Bool bCurrent = IS_TYPE( SwPagePreView, pViewShell );
+ sal_Bool bCurrent = IS_TYPE( SwPagePreview, pViewShell );
- while( pTmpFrm ) // search PreView
+ while( pTmpFrm ) // search Preview
{
if( IS_TYPE( SwView, pTmpFrm->GetViewShell()) )
bOnly = false;
- else if( IS_TYPE( SwPagePreView, pTmpFrm->GetViewShell()))
+ else if( IS_TYPE( SwPagePreview, pTmpFrm->GetViewShell()))
{
pTmpFrm->GetFrame().Appear();
bFound = true;
@@ -433,7 +433,7 @@ void SwDocShell::Execute(SfxRequest& rReq)
if( nSlotId )
{
// PagePreView in the WebDocShell
// is found under Id ViewShell2.
if( ISA(SwWebDocShell) && SID_VIEWSHELL1 == nSlotId )
nSlotId = SID_VIEWSHELL2;
@@ -433,7 +433,7 @@ void SwDocShell::Execute(SfxRequest& rReq)
if( nSlotId )
{
- // PagePreView in the WebDocShell
+ // PagePreview in the WebDocShell
// is found under Id ViewShell2.
if( ISA(SwWebDocShell) && SID_VIEWSHELL1 == nSlotId )